/*
 * Project: irond
 * Package: src.de.fhhannover.inform.iron.dhcp.util
 * File:    PropertiesReader.java
 *
 * Copyright (C) 2010 Fachhochschule Hannover
 * Ricklinger Stadtweg 118, 30459 Hannover, Germany 
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.fhhannover.inform.iron.dhcp.util;

import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;
import java.util.Properties;

/**
 * Based on Tobias old PropertiesReader, but a bit simplified. We assume the
 * config file will never change...
 */
public class PropertiesReader {

	private Properties mProps;

	public PropertiesReader(String file) {
		loadPropertiesFile(file);
	}

	private void loadPropertiesFile(String file) {

		mProps = new Properties();
		try {
			mProps.load(new FileReader(file));
		} catch (FileNotFoundException e) {
			System.err.println("[irondhcp] Unable to open config " + file);
			throw new RuntimeException(e.getMessage());
		} catch (IOException e) {
			System.err.println("[irondhcp] Unable to read config: "
					+ e.getMessage());
			throw new RuntimeException(e.getMessage());
		}
	}

	public String getProperty(String key) {
		return mProps.getProperty(key);
	}
}
